@@ -231,7 +231,7 @@ fn test_lookup_country() {
 
     let ip: IpAddr = FromStr::from_str("89.160.20.112").unwrap();
     let country: Country = reader.lookup(ip).unwrap();
-    let country: super::geoip2::model::Country = country.country.unwrap();
+    let country = country.country.unwrap();
 
     assert_eq!(country.iso_code, Some("SE"));
     assert_eq!(country.is_in_european_union, Some(true));
@@ -335,6 +335,53 @@ fn test_lookup_asn() {
     assert_eq!(asn.autonomous_system_organization, Some("Telstra Pty Ltd"));
 }
 
+#[test]
+fn test_within_city() {
+    use super::geoip2::City;
+    use super::Within;
+    use ipnetwork::IpNetwork;
+
+    let _ = env_logger::try_init();
+
+    let filename = "test-data/test-data/GeoIP2-City-Test.mmdb";
+
+    let reader = Reader::open_readfile(filename).unwrap();
+
+    let ip_net = IpNetwork::V6("::/0".parse().unwrap());
+
+    let mut iter: Within<City, _> = reader.within(ip_net).unwrap();
+
+    // Make sure the first is what we expect it to be
+    let item = iter.next().unwrap().unwrap();
+    assert_eq!(item.ip_net, IpNetwork::V4("2.2.3.0/24".parse().unwrap()));
+    assert_eq!(item.info.city.unwrap().geoname_id, Some(2655045));
+
+    let mut n = 1;
+    for _ in iter {
+        n += 1;
+    }
+
+    // Make sure we had the expected number
+    assert_eq!(n, 243);
+
+    // A second run through this time a specific network
+    let specific = IpNetwork::V4("81.2.69.0/24".parse().unwrap());
+    let mut iter: Within<City, _> = reader.within(specific).unwrap();
+    // Make sure we have the expected blocks/info
+    let mut expected = vec![
+        // Note: reversed so we can use pop
+        IpNetwork::V4("81.2.69.192/28".parse().unwrap()),
+        IpNetwork::V4("81.2.69.160/27".parse().unwrap()),
+        IpNetwork::V4("81.2.69.144/28".parse().unwrap()),
+        IpNetwork::V4("81.2.69.142/31".parse().unwrap()),
+    ];
+    while !expected.is_empty() {
+        let e = expected.pop().unwrap();
+        let item = iter.next().unwrap().unwrap();
+        assert_eq!(item.ip_net, e);
+    }
+}
+
 fn check_metadata<T: AsRef<[u8]>>(reader: &Reader<T>, ip_version: usize, record_size: usize) {
     let metadata = &reader.metadata;
 
@@ -394,7 +441,7 @@ fn check_ip<T: AsRef<[u8]>>(reader: &Reader<T>, ip_version: usize) {
     }
 
     for subnet in &subnets {
-        let ip: IpAddr = FromStr::from_str(&subnet).unwrap();
+        let ip: IpAddr = FromStr::from_str(subnet).unwrap();
         let value: IpType = reader.lookup(ip).unwrap();
 
         assert_eq!(value.ip, *subnet);
